@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 use File::chdir;
-use FFI::CheckLib 0.11 qw( find_lib_or_exit );
+use FFI::CheckLib 0.11 qw( find_lib_or_die );
 use File::Copy qw( copy );
 use Path::Tiny ();
 use FFI::Build::File::Base 1.00 ();
@@ -14,7 +14,7 @@ use constant default_suffix => '.toml';
 use constant default_encoding => ':utf8';
 
 # ABSTRACT
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 
 sub accept_suffix
@@ -63,14 +63,14 @@ sub build_item
     my @cmd = ('cargo', 'test', @cargo_flags);
     print "+@cmd\n";
     system @cmd;
-    exit 2 if $?;
+    die "error running cargo test" if $?;
 
     @cmd = ('cargo', 'build', @cargo_flags);
     print "+@cmd\n";
     system @cmd;
-    exit 2 if $?;
+    die "error running cargo build" if $?;
 
-    my($dl) = find_lib_or_exit
+    my($dl) = find_lib_or_die
       lib        => '*',
       libpath    => "$CWD/target/release",
       systempath => [],
@@ -128,7 +128,7 @@ FFI::Build::File::Cargo
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
